@@ -28,7 +28,7 @@ try:
 except ImportError:
     pass
 
-__version__ = '0.9.5'
+__version__ = '0.9.6'
 __version_info__ = __version__.split('.')
 
 CTPP2_VERSION = (2, 6)
@@ -47,7 +47,10 @@ def extract_i18n_messages(fileobj, keywords, comment_tags, options):
     :rtype: ``iterator``
     """
     string = r'(([^"]|(\"))+?)'
-    pattern = r'<TMPL_var\s+(_|GETTEXT)\s*[(]\s*"%s ( ("\s*[)]\s*>) | $ )' % string
+    pattern = r"""
+        <TMPL_var\s+(_|GETTEXT)\s*
+        [(]\s*
+        " %s ((")|$)""" % string
     regexp = re.compile(pattern, re.IGNORECASE|re.VERBOSE)
     string_tail_pat = re.compile('^%s"' % string)
     string_part_pat = re.compile('^%s$' % string)
@@ -61,11 +64,8 @@ def extract_i18n_messages(fileobj, keywords, comment_tags, options):
             matched = string_tail_pat.search(line)
             if matched:
                 messages.append(buffered + '\n' + matched.group(1))
-                messages = tuple(messages)
-                if len(messages) == 1:
-                    messages = messages[0]
-
-                yield saved_lineno, None, messages, []
+                for message in messages:
+                    yield saved_lineno, None, message, []
                 messages = []
                 buffered = None
             else:
@@ -81,11 +81,7 @@ def extract_i18n_messages(fileobj, keywords, comment_tags, options):
                     break
                 messages.append(matched.group(2))
             else:
-                messages = tuple(messages)
-                if len(messages) == 1:
-                    messages = messages[0]
-
-                if messages:
-                    yield lineno, None, messages, []
+                for message in messages:
+                    yield lineno, None, message, []
                 messages = []
 
